@@ -1,5 +1,32 @@
 
-pub use std::error::Error as ErrorTrait;
+/// Alias for std::error::Error.
+
+pub use std::error::Error as ErrorAdapter;
+
+///
+/// Macro to generate error.
+///
+/// # Sample
+/// ```
+/// # use werror::*;
+/// err!( "No attr" );
+/// ```
+///
+
+#[ macro_export ]
+macro_rules! err
+{
+
+  ( $msg : expr ) =>
+  {
+    $crate::Error::new( $msg )
+  };
+  ( $msg : expr, $( $arg : expr ),+ ) =>
+  {
+    $crate::Error::new( format!( $msg, $( $arg ),+ ) )
+  };
+
+}
 
 /// baic implementation of generic Error
 
